{ config, pkgs, lib, ... }: {
  imports = [
    # Include the results of the hardware scan.
    ./hardware-configuration.nix
    ./nix-settings.nix
    ./boot.nix
    ./users
    ./.luks-swap.nix
    ./fonts.nix
    ./extra
    ./core
    ./dev
    ./games
    ./hardware
  ];

  # This value determines the NixOS release from which the default
  # settings for stateful data, like file locations and database versions
  # on your system were taken. It's perfectly fine and recommended to leave
  # this value at the release version of the first install of this system.
  # Before changing this value read the documentation for this option
  # (e.g. man configuration.nix or on https://nixos.org/nixos/options.html).
  system.stateVersion = "23.11"; # Did you read the comment?

    hardware.opengl.enable = true;

  networking.firewall.checkReversePath = false;
  networking.hostName = "servostar-nixos-flex"; # Define your hostname.
  # networking.wireless.enable = true;  # Enables wireless support via wpa_supplicant.

  # Configure network proxy if necessary
  # networking.proxy.default = "http://user:password@proxy:port/";
  # networking.proxy.noProxy = "127.0.0.1,localhost,internal.domain";

  # Enable networking
  networking.networkmanager.enable = true;

  # Set your time zone.
  time.timeZone = "Europe/Berlin";

  # Select internationalisation properties.
  i18n.defaultLocale = "en_US.UTF-8";

  i18n.extraLocaleSettings = {
    LC_ADDRESS = "de_DE.UTF-8";
    LC_IDENTIFICATION = "de_DE.UTF-8";
    LC_MEASUREMENT = "de_DE.UTF-8";
    LC_MONETARY = "de_DE.UTF-8";
    LC_NAME = "de_DE.UTF-8";
    LC_NUMERIC = "de_DE.UTF-8";
    LC_PAPER = "de_DE.UTF-8";
    LC_TELEPHONE = "de_DE.UTF-8";
    LC_TIME = "de_DE.UTF-8";
  };

  services.rpcbind.enable = true; # needed for NFS

  programs.partition-manager.enable = true;

  # use bash shell for other users
  environment.shells = with pkgs; [ bash ];

  # Configure console keymap
  console.keyMap = "de";

  ################################################
  #  ____  _                     _
  # |  _ \(_)_ __   _____      _(_)_ __ ___
  # | |_) | | '_ \ / _ \ \ /\ / / | '__/ _ \
  # |  __/| | |_) |  __/\ V  V /| | | |  __/
  # |_|   |_| .__/ \___| \_/\_/ |_|_|  \___|
  #         |_|
  ################################################

  # Enable sound with pipewire.
  sound.enable = true;
  hardware.pulseaudio.enable = false;
  security.rtkit.enable = true;
  services.pipewire = {
    enable = true;
    alsa.enable = true;
    alsa.support32Bit = true;
    pulse.enable = true;
    # If you want to use JACK applications, uncomment this
    #jack.enable = true;

    # use the example session manager (no others are packaged yet so this is enabled by default,
    # no need to redefine it in your config for now)
    #media-session.enable = true;
  };

  # Enable touchpad support (enabled default in most desktopManager).
  # services.xserver.libinput.enable = true;

  # List packages installed in system profile. To search, run:
  # $ nix search wget
  environment.systemPackages = (with pkgs; [
    distrobox

    go

    nodejs

    sass

    devbox
    filelight
    ffmpeg-full
    openssl
    imagemagick
    gnumake
    cmake

    # Clipboard support for Wayland Session
    # used by Vim/Neovim and etc.
    wl-clipboard

    # GNU Compiler Collection and toolchain
    glibc
    gcc
    gdb
    stdenv.cc
    stdenv.cc.libc
    stdenv.cc.libc_dev

    pkg-config
    fontconfig

    # SCSI driver
    sg3_utils

    wineWowPackages.stable
    winetricks
  ]);

  # Some programs need SUID wrappers, can be configured further or are
  # started in user sessions.
  # programs.mtr.enable = true;
  # programs.gnupg.agent = {
  #   enable = true;
  #   enableSSHSupport = true;
  # };

  # List services that you want to enable:

  # Enable the OpenSSH daemon.
  # services.openssh.enable = true;

  # Or disable the firewall altogether.
  # networking.firewall.enable = false;

  environment.sessionVariables = rec {
    # rust
    CARGO_TERM_COLOR = "always";
    RUST_BACKTRACE = "1";

    # Wayland for electron Ozone
    NIXOS_OZONE_WL = "1";

    GTK_THEME = "Breeze-Dark";
  };
}
